@@ -6,15 +6,12 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::KENTNL::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.8.0';
+  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.8.1';
 }
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
 
 use Moose;
-use Moose::Autobox;
-use Class::Load qw( :all );
-
 with 'Dist::Zilla::Role::PluginBundle';
 
 use namespace::autoclean -also => [qw( _expand _defined_or _only_git _only_cpan _release_fail _only_fiveten )];
@@ -188,7 +185,7 @@ sub bundle_config_inner {
     [ 'Test::Perl::Critic'   => {} ],
   );
 
-  my (@prunefiles) = ( [ 'PruneCruft' => { except => '^.perltidyrc' } ], [ 'ManifestSkip' => {} ], );
+  my (@prunefiles) = ( [ 'PruneCruft' => { except => '^.(perltidyrc|travis.yml|proverc)' } ], [ 'ManifestSkip' => {} ], );
 
   my (@regprereqs) = (
     [ 'AutoPrereqs' => { skip => $arg->{auto_prereqs_skip} } ],
@@ -269,13 +266,11 @@ sub bundle_config {
   my $arg = $section->{payload};
 
   my @config = map { _expand( $class, $_->[0], $_->[1] ) } $class->bundle_config_inner($arg);
-  load_class( $_->[1] ) for @config;
   return @config;
 }
 
 __PACKAGE__->meta->make_immutable;
 no Moose;
-
 ## no critic (RequireEndWithOne)
 'I go to prepare a perl module for you, if it were not so, I would have told you';
 
@@ -291,7 +286,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 1.8.0
+version 1.8.1
 
 =head1 SYNOPSIS
 
